@@ -6,7 +6,7 @@ use Log::Any qw/$log/;
 use Exporter::Tidy all =>
   [qw/create_sqlite_sequence create_functions create_methods/];
 
-our $VERSION = "0.0.9_1";
+our $VERSION = "0.0.10";
 
 my %sqlite_functions = (
     debug => sub {
@@ -273,7 +273,7 @@ DBIx::ThinSQL::SQLite - add various functions to SQLite
 
 =head1 VERSION
 
-0.0.9_1 (2014-04-23) Development release.
+0.0.10 (2014-04-23) Development release.
 
 =head1 SYNOPSIS
 
